# Class as highest level game for interitance testing

class Game:
    
    def __init__(self, _hp = 10, _mp = 5):
        self.hp = _hp
        self.mp = _mp

    
    def get_current_hp(self):
        return self.hp

    def set_hp(self, _hp):
        self.hp = _hp

    def show_hp(self):
        print('current hp = ',self.hp)


from .GameClass import Game

class Character(Game):

    def __init__(self, _char_type = 'hero', _hp=12,_mp=2):
        Game.__init__(self, _hp,_mp)
        self.char_type = _char_type

    def change_to_hero(self):
        self.char_type = 'hero'

    def change_to_human(self):
        self.char_type = 'human'

    def change_to_npc(self):
        self.char_type = 'npc'

    def change_to_slave(self):
        self.char_type = 'slave'

    def show_type(self):
        print('current character type: ', self.char_type)
        return self.char_type


# from .Game import Game
from .CharacterClass import Character

class Animal(Character):

    def __init__(self, _type = 'penguin', _hp = 10, _mp=5):
        Character.__init__(self, 'npc',_hp, _mp)
        self.type = _type

    def animal_bark(self):
        print('anime bark with type: ', self.type)
        return self.type



from setuptools import setup

setup(name='pete_game_test1',
      version='0.2',
      description='test pete game upload',
      packages=['pete_game_test'],
      author='Pete Tae',
      email='pete.taecha@gmail.com',
      zip_safe=False)
